/* ---------------------------------------------------------------------------------------
 * @file:    startup_LPC8N04.s
 * @purpose: CMSIS Cortex-M0 Core Device Startup File for the LPC8N04
 * @version: 1.0
 * @date:    2018-6-21
 * ---------------------------------------------------------------------------------------*/
/*
 * Copyright 1997-2016 Freescale Semiconductor, Inc.
 * Copyright 2016-2019 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */
/*****************************************************************************/
/* Version: GCC for ARM Embedded Processors                                  */
/*****************************************************************************/

    .syntax unified
    .arch armv6-m
    .eabi_attribute Tag_ABI_align_preserved, 1 /*8-byte alignment */

    .section .isr_vector, "a"
    .align 2
    .globl __Vectors

__Vectors:
    .long    Image$$ARM_LIB_STACK$$ZI$$Limit                 /* Top of Stack */
    .long    Reset_Handler                                   /* Reset Handler */
    .long    NMI_Handler                                     /* NMI Handler*/
    .long    HardFault_Handler                               /* Hard Fault Handler*/
    .long    0                                               /* Reserved*/
    .long    0                                               /* Reserved*/
    .long    0                                               /* Reserved*/
    .long    0                                               /* Reserved*/
    .long    0                                               /* Reserved*/
    .long    0                                               /* Reserved*/
    .long    0                                               /* Reserved*/
    .long    SVC_Handler                                     /* SVCall Handler*/
    .long    0                                               /* Reserved*/
    .long    0                                               /* Reserved*/
    .long    PendSV_Handler                                  /* PendSV Handler*/
    .long    SysTick_Handler                                 /* SysTick Handler*/

                                                            /* External Interrupts*/
    .long    PIO0_0_IRQHandler                              /* PIO0_0 Start Logic Interrupt */
    .long    PIO0_1_IRQHandler                              /* PIO0_1 Start Logic Interrupt */
    .long    PIO0_2_IRQHandler                              /* PIO0_2 Start Logic Interrupt */
    .long    PIO0_3_IRQHandler                              /* PIO0_3 Start Logic Interrupt */
    .long    PIO0_4_IRQHandler                              /* PIO0_4 Start Logic Interrupt */
    .long    PIO0_5_IRQHandler                              /* PIO0_5 Start Logic Interrupt */
    .long    PIO0_6_IRQHandler                              /* PIO0_6 Start Logic Interrupt */
    .long    PIO0_7_IRQHandler                              /* PIO0_7 Start Logic Interrupt */
    .long    PIO0_8_IRQHandler                              /* PIO0_8 Start Logic Interrupt */
    .long    PIO0_9_IRQHandler                              /* PIO0_9 Start Logic Interrupt */
    .long    PIO0_10_IRQHandler                              /* PIO0_10 Start Logic Interrupt */
    .long    RFFIELD_IRQHandler                              /* NFC Access Start Logic Interrupt */
    .long    RTCPWREQ_IRQHandler                              /* RTC Wakeup Request Start Logic Interrupt */
    .long    NFC_IRQHandler                              /* NFC Read/Write Interrupt */
    .long    RTC_IRQHandler                              /* RTC Wakeup Interrupt */
    .long    I2C0_IRQHandler                              /* I2C0 Interrupt */
    .long    CTIMER0_IRQHandler                              /* 16-bit Timer 0 Interrupt */
    .long    PMUFLD_IRQHandler                              /* RF Power Detection Interrupt */
    .long    CTIMER1_IRQHandler                              /* 32-bit Timer 0 Interrupt */
    .long    PMUBOD_IRQHandler                              /* Brown Out Detection Interrupt */
    .long    SSP0_IRQHandler                              /* SSP0 Interrupt */
    .long    TSEN_IRQHandler                              /* Temperature Sensor Interrupt */
    .long    C2D_IRQHandler                              /* Capacitance-to-Digital converter Interrupt */
    .long    Reserved39_IRQHandler                              /* Reserved interrupt */
    .long    I2D_IRQHandler                              /* Current-to-Digital converter Interrupt */
    .long    ADCDAC_IRQHandler                              /* Analog-to-Digital/Digital-to-Analog converter Interrupt */
    .long    WDT_IRQHandler                              /* Watchdog Timer Interrupt */
    .long    FLASH_IRQHandler                              /* FLASH memory Interrupt */
    .long    EEPROM_IRQHandler                              /* EEPROM memory Interrupt */
    .long    Reserved45_IRQHandler                              /* Reserved interrupt */
    .long    Reserved46_IRQHandler                              /* Reserved interrupt */
    .long    PIO0_IRQHandler                              /* GPIO Port 0 Interrupt */
    .size    __Vectors, . - __Vectors

    .text
    .thumb

/* Reset Handler */

    .thumb_func
    .align 2
    .globl   Reset_Handler
    .weak    Reset_Handler
    .type    Reset_Handler, %function

Reset_Handler:
    ldr   r0,=SystemInit
    blx   r0
    ldr   r0,=__main
    bx    r0

    .pool
    .size Reset_Handler, . - Reset_Handler

    .align  1
    .thumb_func
    .weak DefaultISR
    .type DefaultISR, %function
DefaultISR:
    ldr r0, =DefaultISR
    bx r0
    .size DefaultISR, . - DefaultISR

    .align 1
    .thumb_func
    .weak NMI_Handler
    .type NMI_Handler, %function
NMI_Handler:
    ldr   r0,=NMI_Handler
    bx    r0
    .size NMI_Handler, . - NMI_Handler

    .align 1
    .thumb_func
    .weak HardFault_Handler
    .type HardFault_Handler, %function
HardFault_Handler:
    ldr   r0,=HardFault_Handler
    bx    r0
    .size HardFault_Handler, . - HardFault_Handler

    .align 1
    .thumb_func
    .weak SVC_Handler
    .type SVC_Handler, %function
SVC_Handler:
    ldr   r0,=SVC_Handler
    bx    r0
    .size SVC_Handler, . - SVC_Handler

    .align 1
    .thumb_func
    .weak PendSV_Handler
    .type PendSV_Handler, %function
PendSV_Handler:
    ldr   r0,=PendSV_Handler
    bx    r0
    .size PendSV_Handler, . - PendSV_Handler

    .align 1
    .thumb_func
    .weak SysTick_Handler
    .type SysTick_Handler, %function
SysTick_Handler:
    ldr   r0,=SysTick_Handler
    bx    r0
    .size SysTick_Handler, . - SysTick_Handler
    .align 1
    .thumb_func
    .weak PIO0_0_IRQHandler
    .type PIO0_0_IRQHandler, %function
PIO0_0_IRQHandler:
    ldr   r0,=PIO0_0_DriverIRQHandler
    bx    r0
    .size PIO0_0_IRQHandler, . - PIO0_0_IRQHandler

    .align 1
    .thumb_func
    .weak PIO0_1_IRQHandler
    .type PIO0_1_IRQHandler, %function
PIO0_1_IRQHandler:
    ldr   r0,=PIO0_1_DriverIRQHandler
    bx    r0
    .size PIO0_1_IRQHandler, . - PIO0_1_IRQHandler

    .align 1
    .thumb_func
    .weak PIO0_2_IRQHandler
    .type PIO0_2_IRQHandler, %function
PIO0_2_IRQHandler:
    ldr   r0,=PIO0_2_DriverIRQHandler
    bx    r0
    .size PIO0_2_IRQHandler, . - PIO0_2_IRQHandler

    .align 1
    .thumb_func
    .weak PIO0_3_IRQHandler
    .type PIO0_3_IRQHandler, %function
PIO0_3_IRQHandler:
    ldr   r0,=PIO0_3_DriverIRQHandler
    bx    r0
    .size PIO0_3_IRQHandler, . - PIO0_3_IRQHandler

    .align 1
    .thumb_func
    .weak PIO0_4_IRQHandler
    .type PIO0_4_IRQHandler, %function
PIO0_4_IRQHandler:
    ldr   r0,=PIO0_4_DriverIRQHandler
    bx    r0
    .size PIO0_4_IRQHandler, . - PIO0_4_IRQHandler

    .align 1
    .thumb_func
    .weak PIO0_5_IRQHandler
    .type PIO0_5_IRQHandler, %function
PIO0_5_IRQHandler:
    ldr   r0,=PIO0_5_DriverIRQHandler
    bx    r0
    .size PIO0_5_IRQHandler, . - PIO0_5_IRQHandler

    .align 1
    .thumb_func
    .weak PIO0_6_IRQHandler
    .type PIO0_6_IRQHandler, %function
PIO0_6_IRQHandler:
    ldr   r0,=PIO0_6_DriverIRQHandler
    bx    r0
    .size PIO0_6_IRQHandler, . - PIO0_6_IRQHandler

    .align 1
    .thumb_func
    .weak PIO0_7_IRQHandler
    .type PIO0_7_IRQHandler, %function
PIO0_7_IRQHandler:
    ldr   r0,=PIO0_7_DriverIRQHandler
    bx    r0
    .size PIO0_7_IRQHandler, . - PIO0_7_IRQHandler

    .align 1
    .thumb_func
    .weak PIO0_8_IRQHandler
    .type PIO0_8_IRQHandler, %function
PIO0_8_IRQHandler:
    ldr   r0,=PIO0_8_DriverIRQHandler
    bx    r0
    .size PIO0_8_IRQHandler, . - PIO0_8_IRQHandler

    .align 1
    .thumb_func
    .weak PIO0_9_IRQHandler
    .type PIO0_9_IRQHandler, %function
PIO0_9_IRQHandler:
    ldr   r0,=PIO0_9_DriverIRQHandler
    bx    r0
    .size PIO0_9_IRQHandler, . - PIO0_9_IRQHandler

    .align 1
    .thumb_func
    .weak PIO0_10_IRQHandler
    .type PIO0_10_IRQHandler, %function
PIO0_10_IRQHandler:
    ldr   r0,=PIO0_10_DriverIRQHandler
    bx    r0
    .size PIO0_10_IRQHandler, . - PIO0_10_IRQHandler

    .align 1
    .thumb_func
    .weak RFFIELD_IRQHandler
    .type RFFIELD_IRQHandler, %function
RFFIELD_IRQHandler:
    ldr   r0,=RFFIELD_DriverIRQHandler
    bx    r0
    .size RFFIELD_IRQHandler, . - RFFIELD_IRQHandler

    .align 1
    .thumb_func
    .weak RTCPWREQ_IRQHandler
    .type RTCPWREQ_IRQHandler, %function
RTCPWREQ_IRQHandler:
    ldr   r0,=RTCPWREQ_DriverIRQHandler
    bx    r0
    .size RTCPWREQ_IRQHandler, . - RTCPWREQ_IRQHandler

    .align 1
    .thumb_func
    .weak NFC_IRQHandler
    .type NFC_IRQHandler, %function
NFC_IRQHandler:
    ldr   r0,=NFC_DriverIRQHandler
    bx    r0
    .size NFC_IRQHandler, . - NFC_IRQHandler

    .align 1
    .thumb_func
    .weak RTC_IRQHandler
    .type RTC_IRQHandler, %function
RTC_IRQHandler:
    ldr   r0,=RTC_DriverIRQHandler
    bx    r0
    .size RTC_IRQHandler, . - RTC_IRQHandler

    .align 1
    .thumb_func
    .weak I2C0_IRQHandler
    .type I2C0_IRQHandler, %function
I2C0_IRQHandler:
    ldr   r0,=I2C0_DriverIRQHandler
    bx    r0
    .size I2C0_IRQHandler, . - I2C0_IRQHandler

    .align 1
    .thumb_func
    .weak CTIMER0_IRQHandler
    .type CTIMER0_IRQHandler, %function
CTIMER0_IRQHandler:
    ldr   r0,=CTIMER0_DriverIRQHandler
    bx    r0
    .size CTIMER0_IRQHandler, . - CTIMER0_IRQHandler

    .align 1
    .thumb_func
    .weak PMUFLD_IRQHandler
    .type PMUFLD_IRQHandler, %function
PMUFLD_IRQHandler:
    ldr   r0,=PMUFLD_DriverIRQHandler
    bx    r0
    .size PMUFLD_IRQHandler, . - PMUFLD_IRQHandler

    .align 1
    .thumb_func
    .weak CTIMER1_IRQHandler
    .type CTIMER1_IRQHandler, %function
CTIMER1_IRQHandler:
    ldr   r0,=CTIMER1_DriverIRQHandler
    bx    r0
    .size CTIMER1_IRQHandler, . - CTIMER1_IRQHandler

    .align 1
    .thumb_func
    .weak PMUBOD_IRQHandler
    .type PMUBOD_IRQHandler, %function
PMUBOD_IRQHandler:
    ldr   r0,=PMUBOD_DriverIRQHandler
    bx    r0
    .size PMUBOD_IRQHandler, . - PMUBOD_IRQHandler

    .align 1
    .thumb_func
    .weak SSP0_IRQHandler
    .type SSP0_IRQHandler, %function
SSP0_IRQHandler:
    ldr   r0,=SSP0_DriverIRQHandler
    bx    r0
    .size SSP0_IRQHandler, . - SSP0_IRQHandler

    .align 1
    .thumb_func
    .weak TSEN_IRQHandler
    .type TSEN_IRQHandler, %function
TSEN_IRQHandler:
    ldr   r0,=TSEN_DriverIRQHandler
    bx    r0
    .size TSEN_IRQHandler, . - TSEN_IRQHandler

    .align 1
    .thumb_func
    .weak C2D_IRQHandler
    .type C2D_IRQHandler, %function
C2D_IRQHandler:
    ldr   r0,=C2D_DriverIRQHandler
    bx    r0
    .size C2D_IRQHandler, . - C2D_IRQHandler

    .align 1
    .thumb_func
    .weak Reserved39_IRQHandler
    .type Reserved39_IRQHandler, %function
Reserved39_IRQHandler:
    ldr   r0,=Reserved39_DriverIRQHandler
    bx    r0
    .size Reserved39_IRQHandler, . - Reserved39_IRQHandler

    .align 1
    .thumb_func
    .weak I2D_IRQHandler
    .type I2D_IRQHandler, %function
I2D_IRQHandler:
    ldr   r0,=I2D_DriverIRQHandler
    bx    r0
    .size I2D_IRQHandler, . - I2D_IRQHandler

    .align 1
    .thumb_func
    .weak ADCDAC_IRQHandler
    .type ADCDAC_IRQHandler, %function
ADCDAC_IRQHandler:
    ldr   r0,=ADCDAC_DriverIRQHandler
    bx    r0
    .size ADCDAC_IRQHandler, . - ADCDAC_IRQHandler

    .align 1
    .thumb_func
    .weak WDT_IRQHandler
    .type WDT_IRQHandler, %function
WDT_IRQHandler:
    ldr   r0,=WDT_DriverIRQHandler
    bx    r0
    .size WDT_IRQHandler, . - WDT_IRQHandler

    .align 1
    .thumb_func
    .weak FLASH_IRQHandler
    .type FLASH_IRQHandler, %function
FLASH_IRQHandler:
    ldr   r0,=FLASH_DriverIRQHandler
    bx    r0
    .size FLASH_IRQHandler, . - FLASH_IRQHandler

    .align 1
    .thumb_func
    .weak EEPROM_IRQHandler
    .type EEPROM_IRQHandler, %function
EEPROM_IRQHandler:
    ldr   r0,=EEPROM_DriverIRQHandler
    bx    r0
    .size EEPROM_IRQHandler, . - EEPROM_IRQHandler

    .align 1
    .thumb_func
    .weak Reserved45_IRQHandler
    .type Reserved45_IRQHandler, %function
Reserved45_IRQHandler:
    ldr   r0,=Reserved45_DriverIRQHandler
    bx    r0
    .size Reserved45_IRQHandler, . - Reserved45_IRQHandler

    .align 1
    .thumb_func
    .weak Reserved46_IRQHandler
    .type Reserved46_IRQHandler, %function
Reserved46_IRQHandler:
    ldr   r0,=Reserved46_DriverIRQHandler
    bx    r0
    .size Reserved46_IRQHandler, . - Reserved46_IRQHandler

    .align 1
    .thumb_func
    .weak PIO0_IRQHandler
    .type PIO0_IRQHandler, %function
PIO0_IRQHandler:
    ldr   r0,=PIO0_DriverIRQHandler
    bx    r0
    .size PIO0_IRQHandler, . - PIO0_IRQHandler

/*    Macro to define default handlers. Default handler
 *    will be weak symbol and just dead loops. They can be
 *    overwritten by other handlers */
    .macro def_irq_handler  handler_name
    .weak \handler_name
    .set  \handler_name, DefaultISR
    .endm
/* Exception Handlers */
    def_irq_handler    PIO0_0_DriverIRQHandler              /* PIO0_0 Start Logic Interrupt */
    def_irq_handler    PIO0_1_DriverIRQHandler              /* PIO0_1 Start Logic Interrupt */
    def_irq_handler    PIO0_2_DriverIRQHandler              /* PIO0_2 Start Logic Interrupt */
    def_irq_handler    PIO0_3_DriverIRQHandler              /* PIO0_3 Start Logic Interrupt */
    def_irq_handler    PIO0_4_DriverIRQHandler              /* PIO0_4 Start Logic Interrupt */
    def_irq_handler    PIO0_5_DriverIRQHandler              /* PIO0_5 Start Logic Interrupt */
    def_irq_handler    PIO0_6_DriverIRQHandler              /* PIO0_6 Start Logic Interrupt */
    def_irq_handler    PIO0_7_DriverIRQHandler              /* PIO0_7 Start Logic Interrupt */
    def_irq_handler    PIO0_8_DriverIRQHandler              /* PIO0_8 Start Logic Interrupt */
    def_irq_handler    PIO0_9_DriverIRQHandler              /* PIO0_9 Start Logic Interrupt */
    def_irq_handler    PIO0_10_DriverIRQHandler              /* PIO0_10 Start Logic Interrupt */
    def_irq_handler    RFFIELD_DriverIRQHandler              /* NFC Access Start Logic Interrupt */
    def_irq_handler    RTCPWREQ_DriverIRQHandler              /* RTC Wakeup Request Start Logic Interrupt */
    def_irq_handler    NFC_DriverIRQHandler              /* NFC Read/Write Interrupt */
    def_irq_handler    RTC_DriverIRQHandler              /* RTC Wakeup Interrupt */
    def_irq_handler    I2C0_DriverIRQHandler              /* I2C0 Interrupt */
    def_irq_handler    CTIMER0_DriverIRQHandler              /* 16-bit Timer 0 Interrupt */
    def_irq_handler    PMUFLD_DriverIRQHandler              /* RF Power Detection Interrupt */
    def_irq_handler    CTIMER1_DriverIRQHandler              /* 32-bit Timer 0 Interrupt */
    def_irq_handler    PMUBOD_DriverIRQHandler              /* Brown Out Detection Interrupt */
    def_irq_handler    SSP0_DriverIRQHandler              /* SSP0 Interrupt */
    def_irq_handler    TSEN_DriverIRQHandler              /* Temperature Sensor Interrupt */
    def_irq_handler    C2D_DriverIRQHandler              /* Capacitance-to-Digital converter Interrupt */
    def_irq_handler    Reserved39_DriverIRQHandler              /* Reserved interrupt */
    def_irq_handler    I2D_DriverIRQHandler              /* Current-to-Digital converter Interrupt */
    def_irq_handler    ADCDAC_DriverIRQHandler              /* Analog-to-Digital/Digital-to-Analog converter Interrupt */
    def_irq_handler    WDT_DriverIRQHandler              /* Watchdog Timer Interrupt */
    def_irq_handler    FLASH_DriverIRQHandler              /* FLASH memory Interrupt */
    def_irq_handler    EEPROM_DriverIRQHandler              /* EEPROM memory Interrupt */
    def_irq_handler    Reserved45_DriverIRQHandler              /* Reserved interrupt */
    def_irq_handler    Reserved46_DriverIRQHandler              /* Reserved interrupt */
    def_irq_handler    PIO0_DriverIRQHandler              /* GPIO Port 0 Interrupt */

    .end
